==> rho-common-facade-1.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/c/CTraining.java <==
package cn.smarthse.rho.modules.sys.entity.c;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import java.time.LocalDate;
import com.baomidou.mybatisplus.annotation.TableId;
import java.io.Serializable;
import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 员工：放射卫生培训概要
 * </p>
 *
 * @author chenliang
 * @since 2024-06-03
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("c_training")
@ApiModel(value="CTraining对象", description="员工：放射防护培训档案")
public class CTraining implements Serializable {

    private static final long serialVersionUID = 1L;

    @TableId(value = "id")
    private Long id;

    /**
     *
     */
    @ApiModelProperty(value = "培训系统培训id")
    private Long sourceTrainingId;
    /**
     *
     */
    @ApiModelProperty(value = "培训系统用户报名id")
    private Long sourceEnrollId;
    /**
     *
     */
    @ApiModelProperty(value = "来源（1-在线培训）")
    private Integer source;
    /**
     *
     */
    @ApiModelProperty(value = "培训名称")
    private String trainName;
    /**
     *
     */
    @ApiModelProperty(value = "培训类型（初次培训（岗前）；继续教育（岗中））")
    private String trainType;
    /**
     *
     */
    @ApiModelProperty(value = "培训状态（上架下架）")
    private Integer trainStatus;
    /**
     *
     */
    @ApiModelProperty(value = "培训开始时间")
    private Date trainBeginDate;
    /**
     *
     */
    @ApiModelProperty(value = "培训结束时间")
    private Date trainEndDate;
    /**
     *
     */
    @ApiModelProperty(value = "证书类型")
    private String certType;
    /**
     *
     */
    @ApiModelProperty(value = "上报时间")
    private Date reportTime;
    /**
     *
     */
    @ApiModelProperty(value = "登记人")
    private String registrant;
    /**
     *
     */
    @ApiModelProperty(value = "培训发布地区id")
    private Long areaId;
    /**
     *
     */
    @ApiModelProperty(value = "培训发布地区")
    private String address;
    /**
     *
     */
    @ApiModelProperty(value = "培训机构名称")
    private String trainCompanyName;

    @ApiModelProperty(value = "是否有效")
    private Boolean isValid;

    @ApiModelProperty(value = "取证人数")
    private Integer getCertNum;
}

==> rho-common-facade-2.0.0-sources.jar: cn/smarthse/rho/modules/sys/entity/c/CTraining.java <==
package cn.smarthse.rho.modules.sys.entity.c;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.util.Date;



/**
 * <p>
 * 员工：放射卫生培训概要
 * </p>
 *
 * @author chenliang
 * @since 2024-06-03
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("c_training")
//@ApiModel(value="CTraining对象", description="员工：放射防护培训档案")
public class CTraining implements Serializable {

    private static final long serialVersionUID = 1L;

    @TableId(value = "id")
    private Long id;

    /**
     *
     */
    //@ApiModelProperty(value = "培训系统培训id")
    private Long sourceTrainingId;
    /**
     *
     */
    //@ApiModelProperty(value = "培训系统用户报名id")
    private Long sourceEnrollId;
    /**
     *
     */
    //@ApiModelProperty(value = "来源（1-在线培训）")
    private Integer source;
    /**
     *
     */
    //@ApiModelProperty(value = "培训名称")
    private String trainName;
    /**
     *
     */
    //@ApiModelProperty(value = "培训类型（初次培训（岗前）；继续教育（岗中））")
    private String trainType;
    /**
     *
     */
    //@ApiModelProperty(value = "培训状态（上架下架）")
    private Integer trainStatus;
    /**
     *
     */
    //@ApiModelProperty(value = "培训开始时间")
    private Date trainBeginDate;
    /**
     *
     */
    //@ApiModelProperty(value = "培训结束时间")
    private Date trainEndDate;
    /**
     *
     */
    //@ApiModelProperty(value = "证书类型")
    private String certType;
    /**
     *
     */
    //@ApiModelProperty(value = "上报时间")
    private Date reportTime;
    /**
     *
     */
    //@ApiModelProperty(value = "登记人")
    private String registrant;
    /**
     *
     */
    //@ApiModelProperty(value = "培训发布地区id")
    private Long areaId;
    /**
     *
     */
    //@ApiModelProperty(value = "培训发布地区")
    private String address;
    /**
     *
     */
    //@ApiModelProperty(value = "培训机构名称")
    private String trainCompanyName;

    //@ApiModelProperty(value = "是否有效")
    private Boolean isValid;

    //@ApiModelProperty(value = "取证人数")
    private Integer getCertNum;
}
